#
# spec file for package YODA
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_name lib%{name}-1_6_7

Name:           YODA
Version:        1.6.7
Release:        lp150.1.4
Summary:        A small set of data analysis classes for MC event generator validation analyses
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://yoda.hepforge.org/
Source:         http://www.hepforge.org/archive/yoda/%{name}-%{version}.tar.bz2
Patch1:         sover.diff
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-Cython
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
YODA is a small set of data analysis (specifically histogramming)
classes being developed by MCnet members as a lightweight common
system for MC event generator validation analyses. 

A few key features of YODA are as follows:
* Storage of all information needed for statistically correct run
  combination and reweighting up to second-order correlations (e.g.
  variances, std devs, etc.) not just in the number of entries in a
  bin, but also the correlations of that with the x and y fill
  values.
* Separation of statistics and data handling from presentation. YODA
  is primarily a library for doing the data part correctly: while we
  love really high quality data presentation, that's a separate goal.
* A sensible class hierarchy for histogramming, recognising that a
  histogram contains details of fill history beyond the pure visual
  height of a bin, and that just counting weights, or binning
  arbitrary types on an axis are valuable operations.
* Flexible data format support, including a new text-based, compact,
  and human-readable YODA format.
* Proper and convenience treatment of "details" like irregular bin
  widths, gaps in contiguous binning, and overflows/underflows/etc.
  (incuding how they impact normalisation and calculation of histo-
  wide stat quantities)
* Carefully designed programming interfaces in C++ and Python. We
  are very welcoming of feedback and design evolution, too!

%package -n %{so_name}
Summary:        A small set of data analysis classes for MC event generator validation analyses
Group:          System/Libraries

%description -n %{so_name}
YODA is a small set of data analysis (specifically histogramming)
classes being developed by MCnet members as a lightweight common
system for MC event generator validation analyses. 

This package provides the source files for development with %{name}.


%package devel
Summary:        A small set of data analysis classes for MC event generator validation analyses
Group:          Development/Libraries/C and C++
Requires:       %{so_name} = %{version}

%description devel
YODA is a small set of data analysis (specifically histogramming)
classes being developed by MCnet members as a lightweight common
system for MC event generator validation analyses. 

This package provides the source files for development with %{name}.

%package -n python-%{name}
Summary:        A small set of data analysis classes for MC event generator validation analyses
Group:          Development/Libraries/Python
Requires:       %{so_name} = %{version}
Requires:       python = %{py_ver}

%description -n python-%{name}
YODA is a small set of data analysis (specifically histogramming)
classes being developed by MCnet members as a lightweight common
system for MC event generator validation analyses. 

This package provides the python binidings for %{name}.

%prep
%setup -q
%patch -P 1 -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install

find %{buildroot}%{_libdir}/ -name "*.la" -delete

# Remove traces of BUILDROOT from files
sed -i "s|%{buildroot}||g" %{buildroot}%{python_sitearch}/yoda/*.pyc

%post   -n %{so_name} -p /sbin/ldconfig
%postun -n %{so_name} -p /sbin/ldconfig

%files -n %{so_name}
%defattr(-,root,root)
%{_libdir}/libYODA-*.so

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING
%{_bindir}/aida2flat
%{_bindir}/aida2yoda
%{_bindir}/flat2yoda
%{_bindir}/yoda2aida
%{_bindir}/yoda2flat
%{_bindir}/yoda2yoda
%{_bindir}/yoda-config
%{_bindir}/yodamerge
%{_bindir}/yodacmp
%{_bindir}/yodacnv
%{_bindir}/yodadiff
%{_bindir}/yodahist
%{_bindir}/yodals
%{_bindir}/yodaplot
%{_bindir}/yodascale
%{_libdir}/libYODA.so
%{_libdir}/pkgconfig/yoda.pc
%{_includedir}/%{name}/
%{_datadir}/%{name}/

%files -n python-%{name}
%defattr(-,root,root)
%{python_sitearch}/yoda/
%{python_sitearch}/yoda*.egg-info

%changelog
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 1.6.7:
  * pyext/yoda/rootcompat.pyx: Fix ordering of TH1 vs. TProfile
    conversion
  * Add static Reader methods to match the Writer ones.
  * Fix Histo2D and Profile2D total distribution reading from YODA
    format.
  * Convert TH1F to TH1D in root2flat. Much simpler than
    duplicating the TH1D stuff in pyext.
- Changes from version 1.6.6:
  * Bugfixes in Cython bins accessors for Histo2D.
  * Fixed warning messages about the obsoleteness of AIDA so that
    the scripts actually still work.
* Mon Feb 13 2017 jengelh@inai.de
- Call ldconfig directly. Add sover.diff, enforce versioning
  as per guidelines.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 1.6.5:
  * Fix handling of --enable/disable-root configure options.
  * Improvements to Cython version testing.
- Numerous changes from last packaged version (1.3.1) through
  version 1.6.4. Please see ChangeLog file for details.
- Drop YODA-boost-configure-for-GCC5.patch: no longer needed due
  to fixes in upstream code.
* Thu Jun 25 2015 badshah400@gmail.com
- Add YODA-boost-configure-for-GCC5.patch to fix autoconf
  boost macros lookup with GCC5; patch taken from boost.m4
  upstream [https://github.com/tsuna/boost.m4].
- Clean up some further remnants of %%buildroot in python
  byte-compiled files.
* Thu Jun 25 2015 badshah400@gmail.com
- Update to version 1.3.1:
  + Adding usefocus optional argument to some mkScatter functions,
    plus the Python bindings.
  + Cleaning up some Python mappings of 2D histogram bin classes.
  + Removing mappings of bin-level fill and scale operations in
    Python.
  + Fix formatting and error handling in Python Bin and Dbn
    __repr__ methods.
  + Add a -i/--in-place option pair on yodascale.
  + Convert script matching options to use re search rather than
    match.
  + Adding matching options and verbose option to yodals.
  + Improvements and additions to ROOTCnv.h routines, particularly
    to TProfile creation: thanks to Roman Lysak for advice.
  + Add convenience YODA/YODA.h header.
  + yodascale now uses PointMatcher and can normalize or multiply
    to abs values or ref histos/bin ranges.
  + Adding yoda.matcher Python sub-package with PointMatcher
    functionality. To be used in Professor 2.0 and in yodascale.
  + Adding 'scat2' type to yodahist.
  + Add match/unmatch args to all conversion scripts, via a new
    Python yoda.script_helpers function.
  + Script updates, improved docstrings, and improved tab
    completion.
  + Add a yoda.plotting sub-module, based on matplotlib.
  + Small build improvements.
  + Handle overflow filling in binned types without invoking an
    exception.
  + Change inRange to have non-fuzzy comparison behaviour.
  + Improving/adding __div__ functions in Python for all binned
    types.
  + Add std:: prefix to isinf() calls in BinSearcher.h.
* Sun Oct 26 2014 badshah400@gmail.com
- Update to version 1.3.0:
  + Use numEntries() rather than effNumEntries() when checking
    consistency of inputs to efficiency() calculations -- the
    effNumEntries of a set can be smaller than that of a strict
    subset, surprisingly!
  + Small improvements to yodahist and yodaplot behaviours/UIs.
  + Adding setX/Y/Z(val, err) methods to Point3D.
  + Add an efficiency method for 2D histos.
  + Hide fill and fillBin methods from Python mappings of bin
    types.
* Thu Sep 18 2014 badshah400@gmail.com
- Update to version 1.2.1:
  + Hide non-const access to bin objects from histogram user:
    avoids potential for inconsistency between total dbns and
    in-range bins.
  + Bug in BinSearcher fixed by Peter Richardson: constructor
    arguments were passed in the wrong order when constructing
    a LinEstimator in cases where log binning wouldn't be
    allowed.
  + Add protection against / characters in histo names in
    yoda2root
  + Add +=, -=, *-, /=, ++ and -- operators to Counter, along
    with an (implicit) constructor from a double -- all for user
    convenience so Counter can be used in lieu of a simple number
- Changes from version 1.2.0:
  + Many changes from 1.1.0 version, please see installed
    ChangeLog file
- Add the new binaries yadals, yodaplot and yodascale to filelist.
* Sat Jun 21 2014 badshah400@gmail.com
- Update to version 1.1.0:
  + YODA 1.1.0 release.
  + Adding unit tests against ref data for yodamerge in make check.
  + Removing 'foreach' macro definition and using raw
    BOOST_FOREACH instead until C++11 is allowed.
  + Adding pytest-p1d and pytest-p2d tests, and FLAT
    writing/reading in pytests.
  + Tweaking WriterFLAT and adding ReaderFLAT functionality for 2D
    histos and profiles.
  + Some basic (FLAT) write-out capability for 2D histos
  + Improvements to the yodahist script, including support for 2D
    histograms and input files.
  + Adding bin edges constructors for all 1D and 2D histos in
    Python.
  + Improvements to Profile2D and Point2D interfaces in Python.
  + Add a single-file at a time yodacnv multi-format converter
    script (thanks to Andrii Verbytskyi for the suggestion).
  + Typo fixes in Profile2D YODA-format parsing: 2D histo tests
    now pass!
  + Adding Python tests for Histo2D and Profile2D.
  + Adding a YODA/Predicates.h header and using it in Axis2D bin
    edge construction.
  + Enabling Profile2D writing in various Writers, and a bit of IO
    code tidying.
  + Disable writing out of Histo2D and Profile2D outflows for now,
    while they are redesigned, and get 2D I/O working for the
    in-range part.
  + Mapping the divide and efficiency functions into the Python
    interface as class methods, including the __div__ special
    function.
  + Add the AnalysisObject::type() method back in Python (even
    though type(ao) is more Pythonic, this may be useful)
  + Add Profile2D YODA format writing, note need for Scatter
    format change, add sumXY storage to both 2D histo types.
  + Adding YODA reader functionality for Histo2D and Profile2D,
    but without outflows support yet.
  + Adding simple command line yodahist script for quick 1D
    histogramming from plain text files, with weight support. More
    development to come!
  + Mapping linspace, logspace and a few stat functions into
    Python.
  + Fixes, script installation, and detailed numerical comparisons
    in yodadiff.
  + Change AnalysisObject::annotations to return the list of
    annotation keys rather than the map, since the previous
    behaviour mapped very badly into Python.
  + Add special case handling for 2-arg use of x2y scripts where
    the second arg is -, for stdin. This will be treated as
    writing out to stdout, not converting two files one of which
    is stdin.
  + Adding a more portable version of getline to be used in the
    YODA file parsing to avoid falling over on DOS-produced input
    files.
  + Adding the namespace protection workaround for Boost described
    at http://www.boost.org/doc/libs/1_55_0/doc/html/foreach.html
  + Adding an assumed-equal-run-size, ratio-like merging heuristic
    for Scatter2Ds to yodamerge, and renaming the --normalize-all
    flag to --assume-normalized.
  + Adding and installing a pkg-config data file for YODA.
  + Rationalising (and fixing?) the yodamerge logic re. user &
    normalization scalings, and making way for a Scatter2D merging
    heuristic
- Packaging changes:
  + Package new binaries yodacnv, yodadiff, yodahist
  + Package new pkgconfig file (buildrequires pkg-config).
* Tue Dec 10 2013 badshah400@gmail.com
- Initial version
